% A series of ChiP-seq derived serquence datasets for the three TFB
% proteins tfbB, tfbD, and tfbG are analyzed here in great detail. This
% long script describes the creation of data sets, MotifCatcher analyses,
% and some of the later output interpretations.
%
% four varieties of motif-search studies carried out.
%
% (0) Initializations/steps necessary for each subset.
%
%   60-mers,
%   100-mers,
%   200-mers,
%   1000-mers
%
% (1) Normal analysis
%     choose a range of n-mer, and tolerance for proximity to similar sites.     
%
% (3) Displaced regions
%     Create 7 datasetes matching the normal analysis, but displaced from
%     the center by a significant offset.
%
% (3) Random regions
%     Create 7 datasets matching the size of datasets from the normal
%     analysis, but fill with random, non-overlapping sections of the
%     genome.
%
% (4) Shuffled datasets
%     After the 7 datasets have been determined for the normal analysis,
%     instead of segmenting the normal datasets into the appropriate
%     groups, create 7 additional datasets matching in size to the original
%     7, but with scrambled content.
%
% (5) note important workspace variables thusfar and save.
%
%  Other analyses worth doing:
%
%   (1) Compare center of motif to center of ChipSeq peak, with TSSs
%   (2) scan whole genome for other instances of the putative motifs, and
%       examine to see where they are.
%       Try this step with a range of E-values.


%% (0) Steps applicable to all analyses.

%all analyses use the same set of sequences (Halobacterium salinarum sp.
%NRC-1)

%Import Sequences
Chromosome = fastaread('/Users/phillipseitzer/Documents/Organism_info/Fasta_unsorted/Halobacterium_salinarum_NRC1_CHR_unsorted.fasta');
PNRC100 = fastaread('/Users/phillipseitzer/Documents/Organism_info/Fasta_unsorted/Halobacterium_salinarum_NRC1_pNRC100_unsorted.fasta');
PNRC200 = fastaread('/Users/phillipseitzer/Documents/Organism_info/Fasta_unsorted/Halobacterium_salinarum_NRC1_pNRC200_unsorted.fasta');

%% (1) Normal analysis, 60-mers

%find a good tolerance
tfbInfo{1,1} = 'tfbB';
tfbInfo{1,2} = 'tfbD';
tfbInfo{1,3} = 'tfbG';

tfbInfo{2,1} = '/Users/phillipseitzer/Documents/Organism_info/11.08_peaks_fdr_01/tfbB.binding.positions.txt';
tfbInfo{2,2} = '/Users/phillipseitzer/Documents/Organism_info/11.08_peaks_fdr_01/tfbD.binding.positions.txt';
tfbInfo{2,3} = '/Users/phillipseitzer/Documents/Organism_info/11.08_peaks_fdr_01/tfbG.binding.positions.txt';

%initialize
DataSetSizes = zeros(200,7);

%compute segmentation breakdown.
for i = 1:200
    [~, Sitelist] = tfbAny3(tfbInfo,i);
    for j = 1:7
       DataSetSizes(i,j) = length(Sitelist{1,j}); 
    end
    
    %optional print statement.
    disp(['Tolerance ' num2str(i) ' Computed.']);
    
end

%based on these results, a tolerance between 26-33 inclusive produces an identical
%breakdown.  This seems like a natural breakpoint, so tol=30 nt is used.

%next: how to choose a range?
%select a range of +/- 30 from the site.

%create cell structure
tolerance = 30;
[AllSites Sitelist] = tfbAny3(tfbInfo,tolerance);

%define ranges
Urange = 30;
Drange = 30;


%define output file names
outputfilenames = ...
    {'/Users/phillipseitzer/Documents/MotifCatcher_Runs/Data/Normal/tfbB.fasta',...
    '/Users/phillipseitzer/Documents/MotifCatcher_Runs/Data/Normal/tfbD.fasta',...
    '/Users/phillipseitzer/Documents/MotifCatcher_Runs/Data/Normal/tfbG.fasta',...
    '/Users/phillipseitzer/Documents/MotifCatcher_Runs/Data/Normal/tfbBD.fasta',...
    '/Users/phillipseitzer/Documents/MotifCatcher_Runs/Data/Normal/tfbBG.fasta',...
    '/Users/phillipseitzer/Documents/MotifCatcher_Runs/Data/Normal/tfbDG.fasta',...
    '/Users/phillipseitzer/Documents/MotifCatcher_Runs/Data/Normal/tfbBDG.fasta',...
    };

%create files.
for i = 1:7
    
tfbRegulationRegions3(Sitelist,i,Urange,Drange,...
    Chromosome,PNRC100,PNRC200,outputfilenames{1,i});

end

%% (1) Normal analysis, 100-mers

%find a good tolerance
tfbInfo{1,1} = 'tfbB';
tfbInfo{1,2} = 'tfbD';
tfbInfo{1,3} = 'tfbG';

tfbInfo{2,1} = '/Users/phillipseitzer/Documents/Organism_info/11.08_peaks_fdr_01/tfbB.binding.positions.txt';
tfbInfo{2,2} = '/Users/phillipseitzer/Documents/Organism_info/11.08_peaks_fdr_01/tfbD.binding.positions.txt';
tfbInfo{2,3} = '/Users/phillipseitzer/Documents/Organism_info/11.08_peaks_fdr_01/tfbG.binding.positions.txt';

%initialize
DataSetSizes = zeros(200,7);

%compute segmentation breakdown.
for i = 1:200
    [~, Sitelist] = tfbAny3(tfbInfo,i);
    for j = 1:7
       DataSetSizes(i,j) = length(Sitelist{1,j}); 
    end
    
    %optional print statement.
    disp(['Tolerance ' num2str(i) ' Computed.']);
    
end

%based on these results, a tolerance between 26-33 inclusive produces an identical
%breakdown.  This seems like a natural breakpoint, so tol=30 nt is used.

%next: how to choose a range?
%select a range of +/- 30 from the site.

%create cell structure
tolerance = 30;
[AllSites Sitelist] = tfbAny3(tfbInfo,tolerance);

%define ranges
Urange = 50;
Drange = 50;

%define output file names
outputfilenames = ...
    {'/Users/phillipseitzer/Documents/MotifCatcher_Runs/Data/Normal100mers/tfbB.fasta',...
    '/Users/phillipseitzer/Documents/MotifCatcher_Runs/Data/Normal100mers/tfbD.fasta',...
    '/Users/phillipseitzer/Documents/MotifCatcher_Runs/Data/Normal100mers/tfbG.fasta',...
    '/Users/phillipseitzer/Documents/MotifCatcher_Runs/Data/Normal100mers/tfbBD.fasta',...
    '/Users/phillipseitzer/Documents/MotifCatcher_Runs/Data/Normal100mers/tfbBG.fasta',...
    '/Users/phillipseitzer/Documents/MotifCatcher_Runs/Data/Normal100mers/tfbDG.fasta',...
    '/Users/phillipseitzer/Documents/MotifCatcher_Runs/Data/Normal100mers/tfbBDG.fasta',...
    };

%create files.
for i = 1:7
    
tfbRegulationRegions3(Sitelist,i,Urange,Drange,...
    Chromosome,PNRC100,PNRC200,outputfilenames{1,i});

end
%% (1) Normal analysis, 200-mers

%find a good tolerance
tfbInfo{1,1} = 'tfbB';
tfbInfo{1,2} = 'tfbD';
tfbInfo{1,3} = 'tfbG';

tfbInfo{2,1} = '/Users/phillipseitzer/Documents/Organism_info/11.08_peaks_fdr_01/tfbB.binding.positions.txt';
tfbInfo{2,2} = '/Users/phillipseitzer/Documents/Organism_info/11.08_peaks_fdr_01/tfbD.binding.positions.txt';
tfbInfo{2,3} = '/Users/phillipseitzer/Documents/Organism_info/11.08_peaks_fdr_01/tfbG.binding.positions.txt';

%initialize
DataSetSizes = zeros(200,7);

%compute segmentation breakdown.
for i = 1:200
    [~, Sitelist] = tfbAny3(tfbInfo,i);
    for j = 1:7
       DataSetSizes(i,j) = length(Sitelist{1,j}); 
    end
    
    %optional print statement.
    disp(['Tolerance ' num2str(i) ' Computed.']);
    
end

%based on these results, a tolerance between 26-33 inclusive produces an identical
%breakdown.  This seems like a natural breakpoint, so tol=30 nt is used.

%next: how to choose a range?
%select a range of +/- 30 from the site.

%create cell structure
tolerance = 30;
[AllSites Sitelist] = tfbAny3(tfbInfo,tolerance);

%define ranges
Urange = 100;
Drange = 100;


%define output file names
outputfilenames = ...
    {'/Users/phillipseitzer/Documents/MotifCatcher_Runs/Data/Normal200mers/tfbB.fasta',...
    '/Users/phillipseitzer/Documents/MotifCatcher_Runs/Data/Normal200mers/tfbD.fasta',...
    '/Users/phillipseitzer/Documents/MotifCatcher_Runs/Data/Normal200mers/tfbG.fasta',...
    '/Users/phillipseitzer/Documents/MotifCatcher_Runs/Data/Normal200mers/tfbBD.fasta',...
    '/Users/phillipseitzer/Documents/MotifCatcher_Runs/Data/Normal200mers/tfbBG.fasta',...
    '/Users/phillipseitzer/Documents/MotifCatcher_Runs/Data/Normal200mers/tfbDG.fasta',...
    '/Users/phillipseitzer/Documents/MotifCatcher_Runs/Data/Normal200mers/tfbBDG.fasta',...
    };

%create files.
for i = 1:7
    
tfbRegulationRegions3(Sitelist,i,Urange,Drange,...
    Chromosome,PNRC100,PNRC200,outputfilenames{1,i});

end

%% (1) Normal analysis, 1000-mers

%find a good tolerance
tfbInfo{1,1} = 'tfbB';
tfbInfo{1,2} = 'tfbD';
tfbInfo{1,3} = 'tfbG';

tfbInfo{2,1} = '/Users/phillipseitzer/Documents/Organism_info/11.08_peaks_fdr_01/tfbB.binding.positions.txt';
tfbInfo{2,2} = '/Users/phillipseitzer/Documents/Organism_info/11.08_peaks_fdr_01/tfbD.binding.positions.txt';
tfbInfo{2,3} = '/Users/phillipseitzer/Documents/Organism_info/11.08_peaks_fdr_01/tfbG.binding.positions.txt';

%initialize
DataSetSizes = zeros(200,7);

%compute segmentation breakdown.
for i = 1:200
    [~, Sitelist] = tfbAny3(tfbInfo,i);
    for j = 1:7
       DataSetSizes(i,j) = length(Sitelist{1,j}); 
    end
    
    %optional print statement.
    disp(['Tolerance ' num2str(i) ' Computed.']);
    
end

%based on these results, a tolerance between 26-33 inclusive produces an identical
%breakdown.  This seems like a natural breakpoint, so tol=30 nt is used.

%next: how to choose a range?
%select a range of +/- 30 from the site.

%create cell structure
tolerance = 30;
[AllSites Sitelist] = tfbAny3(tfbInfo,tolerance);

%define ranges
Urange = 500;
Drange = 500;


%define output file names
outputfilenames = ...
    {'/Users/phillipseitzer/Documents/MotifCatcher_Runs/Data/Normal1000mers/tfbB.fasta',...
    '/Users/phillipseitzer/Documents/MotifCatcher_Runs/Data/Normal1000mers/tfbD.fasta',...
    '/Users/phillipseitzer/Documents/MotifCatcher_Runs/Data/Normal1000mers/tfbG.fasta',...
    '/Users/phillipseitzer/Documents/MotifCatcher_Runs/Data/Normal1000mers/tfbBD.fasta',...
    '/Users/phillipseitzer/Documents/MotifCatcher_Runs/Data/Normal1000mers/tfbBG.fasta',...
    '/Users/phillipseitzer/Documents/MotifCatcher_Runs/Data/Normal1000mers/tfbDG.fasta',...
    '/Users/phillipseitzer/Documents/MotifCatcher_Runs/Data/Normal1000mers/tfbBDG.fasta',...
    };

%create files.
for i = 1:7
    
tfbRegulationRegions3(Sitelist,i,Urange,Drange,...
    Chromosome,PNRC100,PNRC200,outputfilenames{1,i});

end

%% (2) Displaced Regions

%define ranges
Urange = 90;
Drange = -30;

%define output file names
outputfilenames = ...
    {'/Users/phillipseitzer/Documents/MotifCatcher_Runs/Data/Displaced/tfbB.fasta',...
    '/Users/phillipseitzer/Documents/MotifCatcher_Runs/Data/Displaced/tfbD.fasta',...
    '/Users/phillipseitzer/Documents/MotifCatcher_Runs/Data/Displaced/tfbG.fasta',...
    '/Users/phillipseitzer/Documents/MotifCatcher_Runs/Data/Displaced/tfbBD.fasta',...
    '/Users/phillipseitzer/Documents/MotifCatcher_Runs/Data/Displaced/tfbBG.fasta',...
    '/Users/phillipseitzer/Documents/MotifCatcher_Runs/Data/Displaced/tfbDG.fasta',...
    '/Users/phillipseitzer/Documents/MotifCatcher_Runs/Data/Displaced/tfbBDG.fasta',...
    };

%create files.
for i = 1:7
    
tfbRegulationRegions3(Sitelist,i,Urange,Drange,...
    Chromosome,PNRC100,PNRC200,outputfilenames{1,i});

end

%% (3) Random Regions
%instead of calling the 'tfbRegulationRegions' function, this procedure
%simply extract regions directly.

%initialize outputfile names.
outputfilenames = ...
    {'/Users/phillipseitzer/Documents/MotifCatcher_Runs/Data/Random/tfbB.fasta',...
    '/Users/phillipseitzer/Documents/MotifCatcher_Runs/Data/Random/tfbD.fasta',...
    '/Users/phillipseitzer/Documents/MotifCatcher_Runs/Data/Random/tfbG.fasta',...
    '/Users/phillipseitzer/Documents/MotifCatcher_Runs/Data/Random/tfbBD.fasta',...
    '/Users/phillipseitzer/Documents/MotifCatcher_Runs/Data/Random/tfbBG.fasta',...
    '/Users/phillipseitzer/Documents/MotifCatcher_Runs/Data/Random/tfbDG.fasta',...
    '/Users/phillipseitzer/Documents/MotifCatcher_Runs/Data/Random/tfbBDG.fasta',...
    };

%final coordinates of chromosome/plasmids
CHR_MAX = 2014239;
P100_MAX = 191346;
P200_MAX = 365425;

AllPositions = CHR_MAX+P100_MAX+P200_MAX;

for i = 1:7
   RandCoord = RandPerm(AllPositions); 
   j = 1;
   while(j <= length(Sitelist{1,i}))
            
          %write header  
          Header = strcat('_Random_60-mer_Number_',num2str(j),'_');
       
       if RandCoord(j) > 30 && RandCoord(j) < CHR_MAX-30; %CHR
          
           seq = Chromosome.Sequence(RandCoord(j)-30:RandCoord(j)+30);
           
           fastawrite(outputfilenames{1,i},Header,seq);
           
       elseif RandCoord(j) > CHR_MAX+30 && ... %P100
               RandCoord(j) < CHR_MAX + P100_MAX - 30
           
           coord = RandCoord(j)-CHR_MAX;
           
           seq = PNRC100.Sequence(coord-30:coord+30);
           
           fastawrite(outputfilenames{1,i},Header,seq);
            
       elseif RandCoord(j) > CHR_MAX + P100_MAX + 30 && ... %P200
               RandCoord(j) < CHR_MAX + P100_MAX + P200_MAX-30
           
           coord = RandCoord(j)-CHR_MAX-P100_MAX;
           
           seq = PNRC200.Sequence(coord-30:coord+30);
           
           fastawrite(outputfilenames{1,i},Header,seq);
           
       else
           j = j - 1;
       end
       
       j = j + 1;
       
   end
end

%% (4) Shuffled Regions
%this is accomplished by making an alternative 'Sitelist' structure, and
%sent along to the tfbRegulationRegions() function.

%retrieve every site
EverySite = [];
for i = 1:7
   EverySite = vertcat(EverySite,Sitelist{1,i});
end

%select random permutations, write to structures.
A = Randperm(length(EverySite(:,1)));

SitelistShuffled = cell(1,7);

for i = 1:length(EverySite(:,1))
    if i <= 102
        field = 1;
    elseif i <= 102+96
        field = 2;
    elseif i <= 102+96+126
        field = 3;
    elseif i <= 102+96+126+43
        field = 4;
    elseif i <= 102+96+126+43+40
        field = 5;
    elseif i <= 102+96+126+43+40+26
        field = 6;
    else
        field = 7;
    end
    
    SitelistShuffled{1,field} = ...
        vertcat(SitelistShuffled{1,field},EverySite(A(i),:));
end

%the shuffled site list is simply passed into the function for further
%analysis.

%addition 8-16-2011
counter = 0;
for i = 1:length(SitelistShuffled)
    for j = 1:length(SitelistShuffled{1,i})
        
        %tfbB only
        if ~isempty(strfind(char(SitelistShuffled{1,i}{j,3}),'tfbB')) && ...
            isempty(strfind(char(SitelistShuffled{1,i}{j,3}),'tfbD')) && ...
            isempty(strfind(char(SitelistShuffled{1,i}{j,3}),'tfbG'))
            
            SitelistShuffled{1,i}{j,1} = strcat('b_',char(SitelistShuffled{1,i}{j,1}));
        
        %tfbD only
        elseif isempty(strfind(char(SitelistShuffled{1,i}{j,3}),'tfbB')) && ...
            ~isempty(strfind(char(SitelistShuffled{1,i}{j,3}),'tfbD')) && ...
            isempty(strfind(char(SitelistShuffled{1,i}{j,3}),'tfbG'))
            
            SitelistShuffled{1,i}{j,1} = strcat('d_',char(SitelistShuffled{1,i}{j,1}));
        
        %tfbG only    
        elseif isempty(strfind(char(SitelistShuffled{1,i}{j,3}),'tfbB')) && ...
            isempty(strfind(char(SitelistShuffled{1,i}{j,3}),'tfbD')) && ...
            ~isempty(strfind(char(SitelistShuffled{1,i}{j,3}),'tfbG'))
            
            SitelistShuffled{1,i}{j,1} = strcat('g_',char(SitelistShuffled{1,i}{j,1}));
            
        %tfbBD    
        elseif ~isempty(strfind(char(SitelistShuffled{1,i}{j,3}),'tfbB')) && ...
            ~isempty(strfind(char(SitelistShuffled{1,i}{j,3}),'tfbD')) && ...
            isempty(strfind(char(SitelistShuffled{1,i}{j,3}),'tfbG'))
            
            SitelistShuffled{1,i}{j,1} = strcat('bd_',char(SitelistShuffled{1,i}{j,1}));
            
        %tfbBG    
        elseif ~isempty(strfind(char(SitelistShuffled{1,i}{j,3}),'tfbB')) && ...
            isempty(strfind(char(SitelistShuffled{1,i}{j,3}),'tfbD')) && ...
            ~isempty(strfind(char(SitelistShuffled{1,i}{j,3}),'tfbG'))
            
            SitelistShuffled{1,i}{j,1} = strcat('bg_',char(SitelistShuffled{1,i}{j,1}));
            
        %tfbDG    
        elseif isempty(strfind(char(SitelistShuffled{1,i}{j,3}),'tfbB')) && ...
            ~isempty(strfind(char(SitelistShuffled{1,i}{j,3}),'tfbD')) && ...
            ~isempty(strfind(char(SitelistShuffled{1,i}{j,3}),'tfbG'))
            
            SitelistShuffled{1,i}{j,1} = strcat('dg_',char(SitelistShuffled{1,i}{j,1}));
            
        %tfbBDG
        else
             SitelistShuffled{1,i}{j,1} = strcat('3_',char(SitelistShuffled{1,i}{j,1}));
        end
    end
end

Urange = 30;
Drange = 30;

outputfilenames = ...
    {'/Users/phillipseitzer/Documents/MotifCatcher_Methods/tfbBDG/Datasets/Shuffled/tfbB.fasta',...
    '/Users/phillipseitzer/Documents/MotifCatcher_Methods/tfbBDG/Datasets/Shuffled/tfbD.fasta',...
    '/Users/phillipseitzer/Documents/MotifCatcher_Methods/tfbBDG/Datasets/Shuffled/tfbG.fasta',...
    '/Users/phillipseitzer/Documents/MotifCatcher_Methods/tfbBDG/Datasets/Shuffled/tfbBD.fasta',...
    '/Users/phillipseitzer/Documents/MotifCatcher_Methods/tfbBDG/Datasets/Shuffled/tfbBG.fasta',...
    '/Users/phillipseitzer/Documents/MotifCatcher_Methods/tfbBDG/Datasets/Shuffled/tfbDG.fasta',...
    '/Users/phillipseitzer/Documents/MotifCatcher_Methods/tfbBDG/Datasets/Shuffled/tfbBDG.fasta',...
    };

%create files.
for i = 1:7
    
tfbRegulationRegions3(SitelistShuffled,i,Urange,Drange,...
    Chromosome,PNRC100,PNRC200,outputfilenames{1,i});

end

%% (5) Save significant variables.

save('/Users/phillipseitzer/Documents/MotifCatcher_Runs/Data/FourControls.mat',...
    'A','CHR_MAX','Chromosome','DataSetSizes','EverySite','P100_MAX','P200_MAX',...
    'PNRC100','PNRC200','Sitelist','SitelistShuffled','tfbInfo','tolerance')

%% MEME script [8-16-2011]

%This script runs a MEME ZOOPS on every dataset, and saves to appropriate
%directories.
MEME_root = '/Users/phillipseitzer/Documents/MotifCatcher_Methods/tfbBDG/MEME';
DataSet_root = '/Users/phillipseitzer/Documents/MotifCatcher_Methods/tfbBDG/Datasets';

extensions = {'60bp','Displaced','Random','Shuffled','100bp','200bp','1000bp'};
studies = {'tfbB','tfbBD','tfbBDG','tfbBG','tfbD','tfbDG','tfbG'};

ProgramLocations = struct();
ProgramLocations.FastaGetMarkov = '/Users/phillipseitzer/meme_toplevel/meme/bin/fasta-get-markov';
ProgramLocations.MEME = '/Users/phillipseitzer/meme_toplevel/meme/bin/meme.bin';

%run each MEME ZOOPS run
for i = 1:length(extensions)
   for j = 1:length(studies)
       
        %define data file, and outputdir
        DataFile = strcat(DataSet_root,'/',extensions{1,i},'/',studies{1,j},'.fasta');
        outputdir = strcat(MEME_root,'/',extensions{1,i},'/',studies{1,j});
       
        %build background file
        %import sequences
        [header sequence] = fastaread(DataFile);

        %determine total number of characters in the whole dataset.  This value is
        %used to decide what order of background to use.
        TotalCharacters = 0;
        for k = 1:length(sequence)
            TotalCharacters = TotalCharacters + length(sequence{1,k});
        end

        %determine order of background file based on the total size of all input
        %sequences.
        if TotalCharacters >= 2560
            order = ' 3 ';
        elseif TotalCharacters > 1000
            order = ' 2 ';
        elseif TotalCharacters > 500
            order = ' 1 ';
        else
            order = ' 0 ';
        end

        %Create background file for meme analysis
        bfile = strcat(outputdir,'/bfile.model');
        cmd = strcat(ProgramLocations.FastaGetMarkov,' -m ', order, ' < ', DataFile, ' > ', bfile);
        system(cmd);

        %build MEME cmd
        cmd = [ProgramLocations.MEME ' ' DataFile ' -minw 6 -maxw 30 -dna -bfile ' bfile ' -mod zoops -oc ' outputdir ' -revcomp -maxsize 1000000'];

        %send to command line
        system(cmd)
        
        disp(['Job ' num2str(i) ' subset ' num2str(j) ' completed.']);
   end
end

%display results
key = 7;
for i = length(studies):-1:1
    cmd = ['open ' MEME_root '/' extensions{1,key} '/' studies{1,i} '/meme.html'];
    system(cmd)
end

%% Other Tests

%(1): all ChIP-seq peaks, all together

%input file and output directory
DataFile = '/Users/phillipseitzer/Documents/MotifCatcher_Methods/tfbBDG/OtherTests/AllSites.fasta';
outputdir = '/Users/phillipseitzer/Documents/MotifCatcher_Methods/tfbBDG/OtherTests/AllSites';

order = '3';
%bfile

bfile = strcat(outputdir,'/bfile.model');
cmd = strcat(ProgramLocations.FastaGetMarkov,' -m 3 < ', DataFile, ' > ', bfile);
system(cmd);

cmd = [ProgramLocations.MEME ' ' DataFile ' -minw 6 -maxw 30 -dna -bfile ' bfile ' -mod zoops -oc ' outputdir ' -revcomp -maxsize 1000000'];

% (2) Lists from each raw dataset ('Include' series)
% tfbB, tfbD, and tfbG inclusive
% that 'Sitelist' had to be created carefully-> chose tolerance = 1;
% combine files (worst error no more than 3 or 4 nt)

%create sequences
%define output file names
outputfilenames = ...
    {'/Users/phillipseitzer/Documents/MotifCatcher_Methods/tfbBDG/OtherTests/Include_tfbB.fasta',...
    '/Users/phillipseitzer/Documents/MotifCatcher_Methods/tfbBDG/OtherTests/Include_tfbD.fasta',...
    '/Users/phillipseitzer/Documents/MotifCatcher_Methods/tfbBDG/OtherTests/Include_tfbG.fasta',...
    };

%define ranges
Urange = 30;
Drange = 30;

%create files.
for i = 1:3
    
tfbRegulationRegions3(Sitelist,i,Urange,Drange,...
    Chromosome,PNRC100,PNRC200,outputfilenames{1,i});

end


outputdirs = ...
    {'/Users/phillipseitzer/Documents/MotifCatcher_Methods/tfbBDG/OtherTests/Include_tfbB',...
    '/Users/phillipseitzer/Documents/MotifCatcher_Methods/tfbBDG/OtherTests/Include_tfbD',...
    '/Users/phillipseitzer/Documents/MotifCatcher_Methods/tfbBDG/OtherTests/Include_tfbG',...
    };

for i = 1:3

%input and output    
DataFile = outputfilenames{1,i};
outputdir = outputdirs{1,i};

%make bfile
order = '3';

bfile = strcat(outputdir,'/bfile.model');
cmd = strcat(ProgramLocations.FastaGetMarkov,' -m 3 < ', DataFile, ' > ', bfile);
system(cmd);

%run MEME
cmd = [ProgramLocations.MEME ' ' DataFile ' -minw 6 -maxw 30 -dna -bfile ' bfile ' -mod zoops -oc ' outputdir ' -revcomp -maxsize 1000000'];
system(cmd); 
    
end