function List2RegRegionsv2(SiteList,Urange,Drange,GenomeFile,outputfilename)
%This function creates sequence data sets from a list of ChIP-seq derived
%sites, and an associated genome.
%
%Inputs:
%   Sitelist:
%       array of site coordinates:
%           col 1: title of header
%           col 2: sequence location central value
%           col 3: min range
%           col 4: max range
%           col 5: Name of region
%
%   Urange:
%       number upstream from the central value to extract.
%   Drange:
%       number downstream from the central value to extract.
%   GenomeFile:
%       .fasta file containing 'genome', or section of genome,
%       corresponding to SiteList.
%   outputfilename:
%       name of desired outputfile.
%
%Outputs:
%   <implicit output> desired .fasta files.

%disable append-to-file warning
warning('off','Bioinfo:fastawrite:AppendToFile'); 

%constants
%final coordinates of chromosome/plasmids
[header sequence] = fastaread(GenomeFile);

GEN_MAX = zeros(1,length(sequence));
for i = 1:length(sequence)
    GEN_MAX(i) = length(sequence{1,i});
end

%initialize output file
fastawrite(outputfilename,'','');

for i = 1:length(SiteList(:,1))
    
    %initialize
    TheHeader = -1;
    
    %determine correct sequence to extract
    HeaderName = SiteList{i,1};
    
    for j = 1:length(header)
        if strmatch(header{1,j},HeaderName,'exact')
            TheHeader = j;
            break;
        end
    end    
    
    %catch distance-based errors
    if SiteList{i,2} - Urange < SiteList{i,3}
        start = SiteList{i,3};
    else
        start = SiteList{i,2} - Urange;
    end
    
    if SiteList{i,2} + Drange > SiteList{i,4}
        stop = SiteList{i,4};
    else
        stop = SiteList{i,2} + Drange;
    end
    
    %extract sequence around genomic site
    seq = sequence{1,TheHeader}(start:stop);
    
    %prepare each sequence title
    title = strcat(SiteList{i,5},'-[',num2str(start),':',num2str(stop),']');
    
    %write each section to output file.
    fastawrite(outputfilename,title,seq);
end

end