function MotifFamily2txt(Family,SeqFile,outputfilename,varargin)
%This function generates a .txt file showing the actual sequence in an
%island, the subsequences used to build motifs from the family.
%
%This is later implementation of the function ''
%
%The 'Family' structure is a single family entry from the larger
%'AllMotifsAndLocations' structure.
%
% Revision History:
%    version 1 - Tue 11-1-2011
%
% Inputs:
%   Family:
%       Motif Family, aka subdirectory of 'AllMotifsAndLocations' structure
%   SeqFile:
%       .fasta file
%   outputfilename:
%       output file
%   varargin:
%       variable number of text filters; care only about sequence islands
%       that contain text among the provided variable filters.  If not
%       filters are provided, all sequence islands are equally valuable.
%
% Outputs:
%   <implied output> outputfilename:
%       textual visualization of sequence files taken

%import sequences file
[Header Sequence] = fastaread(SeqFile);

%open outputfile
fid = fopen(outputfilename,'w');

%generate an entry for each sequence entry in the Family.
for i = 1:length(Family(:,1))
    
    %only family entries that are nonempty and meet the requirements put
    %forth in varargin go forward
    Pass = false;
    if isempty(varargin) && ~isempty(Family{i,1})
       Pass = true; 
    else
        if ~isempty(Family{i,1})
            for j = 1:length(varargin)
                if strfind(Family{i,1},varargin{j})
                    Pass = true;
                end
            end
        end
    end

    %Proceed with the visualization, if appropriate.
    if Pass == true
        
        %recover sequence name, and write to file.
        SeqEntry = Family{i,1};
        for j = 1:length(Header);
            if strmatch(SeqEntry,Header{1,j},'exact')
                EntryNum = j;
            end
        end
        fprintf(fid,'%s\n',SeqEntry);
        
        %write sequence entry to file.
        fprintf(fid,'%s%s\n','S:',Sequence{1,EntryNum});
        
        %Add a line for each motif instance.
        SeqCounter = 0;
        
        for j = 2:length(Family(i,:))                    
            if ~isempty(Family{i,j})
                
                %increment counter
                SeqCounter = SeqCounter + 1;
                
                %initialize: sequence island is motif-empty
                MotifInstance = char(1,length(Sequence{1,EntryNum}));
                MotifInstance(1:length(Sequence{1,EntryNum})) = '-';
                
                %modify seqence island to include suggested subsequence
                MotifInstance(min(Family{i,j})) = '[';
                MotifInstance(max(Family{i,j})) = ']';
                
                %write each motif entry to files
                fprintf(fid,'%s%s%d\n','M:',MotifInstance,SeqCounter);
            end
        end
        
        %new entries start on a new line.
        fprintf(fid,'\n');
    end
end

%close outputfile
fclose(fid);