function [OptimalSubsetSize AllPossible]= OptimizeRuns(RealSites,AllSites,RealInSubsetThreshold)
%This function suggests an optimized SubsetSize, based on systems that work
%on a 'subset motif-directed framework'.
%
%%The total number of seeds needed to discover a particular
%motif is a function of the motifs degeneracy and relative prevalence.
%Both of these variables are accounted for here, in the number of 'Real'
%(motif-containing entries) that must be discovered in a seed subset for
%that seed subset to converge to the appropriate motif.
%


%note all possibilities.
AllPossible = zeros(AllSites-1,2);

P=0;
for SubsetSize = 2:AllSites
   
   %determine the number of real cases in this subset, for this subset size. 
   MinRealInSubset = ceil(RealInSubsetThreshold*SubsetSize);
   
   %determine the probability for finding at least the minimum number, for
   %this particular subset size.
   
   Ptotal = 0;
   for NumReal = MinRealInSubset:min(SubsetSize,RealSites)
       
       Prob = (nchoosek(RealSites,NumReal)*nchoosek(AllSites-RealSites,SubsetSize-NumReal))...
    /nchoosek(AllSites,SubsetSize);
       
        Ptotal = Prob + Ptotal;
   end
   
   %write output value to matrix.
   AllPossible(SubsetSize-1,1) = SubsetSize;
   AllPossible(SubsetSize-1,2) = Ptotal;
   
   %If this subset size offers an improved probability, take this value.
   if Ptotal > P
      P = Ptotal;
      OptimalSubsetSize = SubsetSize;
   end
end

end